## $Id: configuration.py 17780 2024-05-13 21:10:53Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Containers for session configuration objects.
"""
import grok
from zope.interface import implementedBy
from waeup.kofa.utils.helpers import attrs_to_fields, iface_names
from waeup.uniben.interfaces import (
    ICustomSessionConfiguration, ICustomSessionConfigurationAdd)
from waeup.kofa.configuration import (
    SessionConfigurationFactory, SessionConfiguration,
    ConfigurationProcessor, ConfigurationExporter)
from waeup.uniben.interfaces import (
    ICustomSessionConfiguration, ICustomSessionConfigurationAdd)


class CustomSessionConfiguration(SessionConfiguration):
    """
    Customized session configuration model
    """

    grok.implements(ICustomSessionConfiguration, ICustomSessionConfigurationAdd)

CustomSessionConfiguration = attrs_to_fields(CustomSessionConfiguration)

class CustomSessionConfigurationFactory(SessionConfigurationFactory):
    """A customized factory for session configuration objects.
    """

    def __call__(self, *args, **kw):
        return CustomSessionConfiguration(*args, **kw)

    def getInterfaces(self):
        return implementedBy(CustomSessionConfiguration)

class CustomConfigurationExporter(ConfigurationExporter):
    """The Configuration Exporter exports all configuration data. It iterates over all
    objects of the ``configuration`` container.
    """
    fields = tuple(sorted(iface_names(ICustomSessionConfiguration)))

class CustomConfigurationProcessor(ConfigurationProcessor):
    """The Configuration Processor processes session configuration objects in
    the ``configuration`` container.

    """
    iface = ICustomSessionConfiguration
